==> qt-creator-2.4.0-src.zip: qt-creator-2.4.0-src/src/plugins/qt4projectmanager/qt-s60/s60runcontrolfactory.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
**
** GNU Lesser General Public License Usage
**
** This file may be used under the terms of the GNU Lesser General Public
** License version 2.1 as published by the Free Software Foundation and
** appearing in the file LICENSE.LGPL included in the packaging of this file.
** Please review the following information to ensure the GNU Lesser General
** Public License version 2.1 requirements will be met:
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights. These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** Other Usage
**
** Alternatively, this file may be used in accordance with the terms and
** conditions contained in a signed written agreement between you and Nokia.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
**
**************************************************************************/

#ifndef S60RUNCONTROLFACTORY_H
#define S60RUNCONTROLFACTORY_H

#include <projectexplorer/runconfiguration.h>

namespace Qt4ProjectManager {
namespace Internal {

class S60RunControlFactory : public ProjectExplorer::IRunControlFactory
{
public:
    explicit S60RunControlFactory(const QString &mode,
                                  const QString &name,
                                  QObject *parent = 0);

    bool canRun(ProjectExplorer::RunConfiguration *runConfiguration, const QString &mode) const;

    ProjectExplorer::RunControl *create(ProjectExplorer::RunConfiguration *runConfiguration, const QString &mode);

    QString displayName() const;

    ProjectExplorer::RunConfigWidget *createConfigurationWidget(ProjectExplorer::RunConfiguration *runConfiguration);

private:
    const QString m_mode;
    const QString m_name;
};

} // namespace Internal
} // namespace Qt4ProjectExplorer

#endif // S60RUNCONTROLFACTORY_H

==> qt-creator-2.5.1-src.zip: qt-creator-2.5.1-src/src/plugins/qt4projectmanager/qt-s60/s60runcontrolfactory.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
**
** GNU Lesser General Public License Usage
**
** This file may be used under the terms of the GNU Lesser General Public
** License version 2.1 as published by the Free Software Foundation and
** appearing in the file LICENSE.LGPL included in the packaging of this file.
** Please review the following information to ensure the GNU Lesser General
** Public License version 2.1 requirements will be met:
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights. These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** Other Usage
**
** Alternatively, this file may be used in accordance with the terms and
** conditions contained in a signed written agreement between you and Nokia.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
**
**************************************************************************/

#ifndef S60RUNCONTROLFACTORY_H
#define S60RUNCONTROLFACTORY_H

#include <projectexplorer/runconfiguration.h>

namespace Qt4ProjectManager {
namespace Internal {

class S60RunControlFactory : public ProjectExplorer::IRunControlFactory
{
public:
    explicit S60RunControlFactory(ProjectExplorer::RunMode mode,
                                  const QString &name,
                                  QObject *parent = 0);

    bool canRun(ProjectExplorer::RunConfiguration *runConfiguration,
                ProjectExplorer::RunMode mode) const;

    ProjectExplorer::RunControl *create(ProjectExplorer::RunConfiguration *runConfiguration,
                                        ProjectExplorer::RunMode mode);

    QString displayName() const;

    ProjectExplorer::RunConfigWidget *createConfigurationWidget(ProjectExplorer::RunConfiguration *runConfiguration);

private:
    const ProjectExplorer::RunMode m_mode;
    const QString m_name;
};

} // namespace Internal
} // namespace Qt4ProjectExplorer

#endif // S60RUNCONTROLFACTORY_H
